@@ -1,6 +1,9 @@
 package Test::BrewBuild::Plugin::UnitTestPluginInst;
 
 sub brewbuild_exec {
+    shift;
+    my $arg = shift;
+    return $arg if defined $arg;
     return "test plugin";
 }
 1;
